==> projectzerorn-ios-chart-0.2.11.tgz: package/RNiOSCharts/RNLineChart.swift <==
//
//  RNLineChart.swift
//  RCTIOSCharts
//
//  Created by Jose Padilla on 12/29/15.
//  Copyright © 2015 Facebook. All rights reserved.
//

import Foundation
import Charts
import SwiftyJSON


@objc(RNLineChart)
class RNLineChart : LineChartView {
    
    override init(frame: CGRect) {
        super.init(frame: frame);
        self.frame = frame;
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented");
    }
    
    func setConfig(config: String!) {
        self.descriptionText = "";
        
        setBarLineChartViewBaseProps(config);
        
        var labels: [String] = [];
        
        var json: JSON = nil;
        if let data = config.dataUsingEncoding(NSUTF8StringEncoding) {
            json = JSON(data: data);
        };
        
        if json["labels"].isExists() {
            labels = json["labels"].arrayObject as! [String];
        }
      
        self.data = getLineData(labels, json: json);
      
        if json["drawMarkers"].isExists() {
          self.drawMarkers = json["drawMarkers"].boolValue;
        }
      
        if json["scaleEnabled"].isExists() {
          self.scaleXEnabled = json["scaleEnabled"].boolValue;
          self.scaleYEnabled = json["scaleEnabled"].boolValue;
        }
      
        if json["touchEnabled"].isExists() {
          self.userInteractionEnabled = json["touchEnabled"].boolValue;
        }
        if json["xAxis"].isExists() && json["xAxis"]["labelsToSkip"]{
          self.xAxis.setLabelsToSkip(json["xAxis"]["labelsToSkip"].intValue);
        }
    }
}

==> projectzerorn-ios-chart-0.2.13.tgz: package/RNiOSCharts/RNLineChart.swift <==
//
//  RNLineChart.swift
//  RCTIOSCharts
//
//  Created by Jose Padilla on 12/29/15.
//  Copyright © 2015 Facebook. All rights reserved.
//

import Foundation
import Charts
import SwiftyJSON


@objc(RNLineChart)
class RNLineChart : LineChartView {
    
    override init(frame: CGRect) {
        super.init(frame: frame);
        self.frame = frame;
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented");
    }
    
    func setConfig(config: String!) {
        self.descriptionText = "";
        
        setBarLineChartViewBaseProps(config);
        
        var labels: [String] = [];
        
        var json: JSON = nil;
        if let data = config.dataUsingEncoding(NSUTF8StringEncoding) {
            json = JSON(data: data);
        };
        
        if json["labels"].isExists() {
            labels = json["labels"].arrayObject as! [String];
        }
      
        self.data = getLineData(labels, json: json);
      
        if json["drawMarkers"].isExists() {
          self.drawMarkers = json["drawMarkers"].boolValue;
        }
      
        if json["scaleEnabled"].isExists() {
          self.scaleXEnabled = json["scaleEnabled"].boolValue;
          self.scaleYEnabled = json["scaleEnabled"].boolValue;
        }
      
        if json["touchEnabled"].isExists() {
          self.userInteractionEnabled = json["touchEnabled"].boolValue;
        }
      
        if json["xAxis"].isExists() && json["xAxis"]["labelsToSkip"].isExists(){
          self.xAxis.setLabelsToSkip(json["xAxis"]["labelsToSkip"].intValue);
        }
      
        if json["leftAxis"].isExists() && json["leftAxis"]["unitLabel"].isExists(){
          let unitFormatter = NSNumberFormatter();
          unitFormatter.numberStyle = .NoStyle;
          unitFormatter.positiveFormat = "#" + json["leftAxis"]["unitLabel"].stringValue;
          self.leftAxis.valueFormatter = unitFormatter;
        }
      
        if json["rightAxis"].isExists() && json["rightAxis"]["unitLabel"].isExists(){
          let unitFormatter = NSNumberFormatter();
          unitFormatter.numberStyle = .NoStyle;
          unitFormatter.positiveFormat = "#" + json["rightAxis"]["unitLabel"].stringValue;
          self.rightAxis.valueFormatter = unitFormatter;
        }
      
    }
}
